'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var jsxRuntime = require('react/jsx-runtime');

const defaultRenderers = {
  inline: {
    bold: 'strong',
    code: 'code',
    keyboard: 'kbd',
    strikethrough: 's',
    italic: 'em',
    link: 'a',
    subscript: 'sub',
    superscript: 'sup',
    underline: 'u',
    relationship: ({
      data
    }) => {
      return /*#__PURE__*/jsxRuntime.jsx("span", {
        children: (data === null || data === void 0 ? void 0 : data.label) || (data === null || data === void 0 ? void 0 : data.id)
      });
    }
  },
  block: {
    block: 'div',
    blockquote: 'blockquote',
    paragraph: ({
      children,
      textAlign
    }) => {
      return /*#__PURE__*/jsxRuntime.jsx("p", {
        style: {
          textAlign
        },
        children: children
      });
    },
    divider: 'hr',
    heading: ({
      level,
      children,
      textAlign
    }) => {
      const Heading = `h${level}`;
      return /*#__PURE__*/jsxRuntime.jsx(Heading, {
        style: {
          textAlign
        },
        children: children
      });
    },
    code: 'pre',
    list: ({
      children,
      type
    }) => {
      const List = type === 'ordered' ? 'ol' : 'ul';
      return /*#__PURE__*/jsxRuntime.jsx(List, {
        children: children.map((x, i) => /*#__PURE__*/jsxRuntime.jsx("li", {
          children: x
        }, i))
      });
    },
    layout: ({
      children,
      layout
    }) => {
      return /*#__PURE__*/jsxRuntime.jsx("div", {
        style: {
          display: 'grid',
          gridTemplateColumns: layout.map(x => `${x}fr`).join(' ')
        },
        children: children.map((element, i) => /*#__PURE__*/jsxRuntime.jsx("div", {
          children: element
        }, i))
      });
    }
  }
};
function DocumentNode({
  node: _node,
  componentBlocks,
  renderers
}) {
  if (typeof _node.text === 'string') {
    let child = /*#__PURE__*/jsxRuntime.jsx(react.Fragment, {
      children: _node.text
    });
    Object.keys(renderers.inline).forEach(markName => {
      if (markName !== 'link' && markName !== 'relationship' && _node[markName]) {
        const Mark = renderers.inline[markName];
        child = /*#__PURE__*/jsxRuntime.jsx(Mark, {
          children: child
        });
      }
    });
    return child;
  }
  const node = _node;
  const children = node.children.map((x, i) => /*#__PURE__*/jsxRuntime.jsx(DocumentNode, {
    node: x,
    componentBlocks: componentBlocks,
    renderers: renderers
  }, i));
  switch (node.type) {
    case 'blockquote':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.blockquote, {
          children: children
        });
      }
    case 'paragraph':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.paragraph, {
          textAlign: node.textAlign,
          children: children
        });
      }
    case 'code':
      {
        if (node.children.length === 1 && node.children[0] && typeof node.children[0].text === 'string') {
          return /*#__PURE__*/jsxRuntime.jsx(renderers.block.code, {
            children: node.children[0].text
          });
        }
        break;
      }
    case 'layout':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.layout, {
          layout: node.layout,
          children: children
        });
      }
    case 'divider':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.divider, {});
      }
    case 'heading':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.heading, {
          textAlign: node.textAlign,
          level: node.level,
          children: children
        });
      }
    case 'component-block':
      {
        const Comp = componentBlocks[node.component];
        if (Comp) {
          const props = createComponentBlockProps(node, children);
          return /*#__PURE__*/jsxRuntime.jsx(renderers.block.block, {
            children: /*#__PURE__*/jsxRuntime.jsx(Comp, {
              ...props
            })
          });
        }
        break;
      }
    case 'ordered-list':
    case 'unordered-list':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.block.list, {
          children: children,
          type: node.type === 'ordered-list' ? 'ordered' : 'unordered'
        });
      }
    case 'relationship':
      {
        const data = node.data;
        return /*#__PURE__*/jsxRuntime.jsx(renderers.inline.relationship, {
          relationship: node.relationship,
          data: data ? {
            id: data.id,
            label: data.label,
            data: data.data
          } : null
        });
      }
    case 'link':
      {
        return /*#__PURE__*/jsxRuntime.jsx(renderers.inline.link, {
          href: node.href,
          children: children
        });
      }
  }
  return /*#__PURE__*/jsxRuntime.jsx(react.Fragment, {
    children: children
  });
}
function set(obj, propPath, value) {
  if (propPath.length === 1) {
    obj[propPath[0]] = value;
  } else {
    const firstElement = propPath.shift();
    set(obj[firstElement], propPath, value);
  }
}
function createComponentBlockProps(node, children) {
  const formProps = JSON.parse(JSON.stringify(node.props));
  node.children.forEach((child, i) => {
    if (child.propPath) {
      const propPath = [...child.propPath];
      set(formProps, propPath, children[i]);
    }
  });
  return formProps;
}
function DocumentRenderer(props) {
  var _props$renderers, _props$renderers2;
  const renderers = {
    inline: {
      ...defaultRenderers.inline,
      ...((_props$renderers = props.renderers) === null || _props$renderers === void 0 ? void 0 : _props$renderers.inline)
    },
    block: {
      ...defaultRenderers.block,
      ...((_props$renderers2 = props.renderers) === null || _props$renderers2 === void 0 ? void 0 : _props$renderers2.block)
    }
  };
  const componentBlocks = props.componentBlocks || {};
  return /*#__PURE__*/jsxRuntime.jsx(react.Fragment, {
    children: props.document.map((x, i) => /*#__PURE__*/jsxRuntime.jsx(DocumentNode, {
      node: x,
      componentBlocks: componentBlocks,
      renderers: renderers
    }, i))
  });
}

exports.DocumentRenderer = DocumentRenderer;
exports.defaultRenderers = defaultRenderers;
